# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2015, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from game.end_to_end_tests.base_game_test import BaseGameTest


class TestGame(BaseGameTest):
    def test_level1(self):
        self.run_level_test(1)

    def test_level2(self):
        self.run_level_test(2)

    def test_level3(self):
        self.run_level_test(3)

    def test_level4(self):
        self.run_level_test(4)

    def test_level5(self):
        self.run_level_test(5)

    def test_level6(self):
        self.run_level_test(6)

    def test_level7(self):
        self.run_level_test(7)

    def test_level8(self):
        self.run_level_test(8)

    def test_level9(self):
        self.run_level_test(9)

    def test_level10(self):
        self.run_level_test(10)

    def test_level11(self):
        self.run_level_test(11)

    def test_level12(self):
        self.run_level_test(12)

    def test_level13(self):
        self.run_level_test(13)

    def test_level14(self):
        self.run_level_test(14)

    def test_level15(self):
        self.run_level_test(15)

    def test_level16(self):
        self.run_level_test(16)

    def test_level17(self):
        self.run_level_test(17)

    def test_level18(self):
        self.run_level_test(18)

    def test_level19(self):
        self.run_level_test(19)

    def test_level20(self):
        self.run_level_test(20)

    def test_level21(self):
        self.run_level_test(21)

    def test_level22(self):
        self.run_level_test(22)

    def test_level23(self):
        self.run_level_test(23)

    def test_level24(self):
        self.run_level_test(24)

    def test_level25(self):
        self.run_level_test(25)

    def test_level26(self):
        self.run_level_test(26)

    def test_level27(self):
        self.run_level_test(27)

    def test_level28(self):
        self.run_level_test(28)

    def test_level29(self):
        self.run_level_test(29)

    def test_level30(self):
        self.run_level_test(30)

    def test_level31(self):
        self.run_level_test(31)

    def test_level32(self):
        self.run_level_test(32)

    def test_level33(self):
        self.run_level_test(33)

    def test_level34(self):
        self.run_level_test(34)

    def test_level35(self):
        self.run_level_test(35)

    def test_level36(self):
        self.run_level_test(36)

    def test_level37(self):
        self.run_level_test(37)

    def test_level38(self):
        self.run_level_test(38)

    def test_level39(self):
        self.run_level_test(39)

    def test_level40(self):
        self.run_level_test(40)

    def test_level41(self):
        self.run_level_test(41)

    def test_level42(self):
        self.run_level_test(42)

    def test_level43(self):
        self.run_level_test(43)

    def test_level44(self):
        self.run_level_test(44)

    def test_level45(self):
        self.run_level_test(45)

    def test_level46(self):
        self.run_level_test(46)

    def test_level47(self):
        self.run_level_test(47)

    def test_level48(self):
        self.run_level_test(48)

    def test_level49(self):
        self.run_level_test(49)

    def test_level50(self):
        self.run_level_test(50)

    #
    # Add levels 51-52
    #

    def test_level53(self):
        self.run_level_test(53)

    #
    # Add levels 54-68
    #

    def test_level69(self):
        self.run_level_test(69, route_score=None)

    def test_level70(self):
        self.run_level_test(70, route_score=None)

    #
    # Add levels 71-72
    #

    def test_level73(self):
        self.run_level_test(73)

    def test_level74(self):
        self.run_level_test(74, route_score=None)

    #
    # Add level 75
    #

    def test_level76(self):
        self.run_level_test(76, route_score=None)

    def test_level77(self):
        self.run_level_test(77, route_score=None)
